@@ -1,5 +1,8 @@
 #!/usr/bin/perl
 
+use warnings;
+use strict;
+
 use Carp qw(confess cluck);
 use Net::DBus;
 use Net::DBus::Service;
@@ -43,7 +46,7 @@ sub GetTuple {
 
 package main;
 
-my $bus = Net::DBus->find();
+my $bus = Net::DBus->session();
 my $service = $bus->export_service("org.designfu.SampleService");
 my $object = SomeObject->new($service);
 
